T-Home előfizetéséhez vagy [freemail] címéhez tartozó jelszavát itt nem változtathatja meg, mert ezzel változna a levelezési jelszava is. A T-Home előfizetéséhez tartozó jelszavát a My T-Home oldalra bejelentkezve változtathatja meg. [freemail] címéhez tartozó adatait a [freemail] oldalára bejelentkezve Beállítások menü Jelszóváltoztatás pontjában változtathatja meg.

További segítség »

# ELFELEJTETT JELSZÓ

## Kérjük, adja meg az e-mail címet, amelyhez a jelszót elfelejtette:

E-mail cím: |